FindedGroup class

This is the big star of this package. A class that delivers far away more information about the named group match then normal Match or RegExpMatch classes.

Constructors

FindedGroup({required String name, required String content, required String fullMatchText, required int start, required int end, required int globalStart, required int globalEnd})
This is the big star of this package. A class that delivers far away more information about the named group match then normal Match or RegExpMatch classes.
const

Properties

content String
The content string of the named group founded.
final
end int
This is the index where the group ends inside the the regex match. Note, this value is not the index where the regex match ends, but where the group ends.
final
fullMatchText String
The full match of the named group. Not only the group content, but the full match of the regex.
final
globalEnd int
Where the regex match ends.
⚠️ Note: This is not the index where the group ends, but where the regex match ends. Thoose values, where the match stats and where it ends, are inside the FindedGroup.start and FindedGroup.end variables.
final
globalStart int
Where the regex match starts.
⚠️ Note: This is not the index where the group starts, but where the regex match starts. Thoose values, where the match stats and where it ends, are inside the FindedGroup.start and FindedGroup.end variables.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the group founded. A.ka. the name of the group in the regex, what stays inside the <>.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
This is the index where the group starts inside the the regex match. Note, this value is not the index where the regex match starts, but where the group starts.
final

Methods

copyWith({String? name, String? content, String? fullMatchText, int? start, int? end, int? globalStart, int? globalEnd}) FindedGroup
Will create a exact copy changing only the parameters you passed in the copyWith function.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited